==> liveness-1.0.2.tar.gz: liveness/src/Controller/LivenessController.php <==
<?php

namespace Drupal\liveness\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;

/**
 * Implements event subscriber for handling LivenessController events.
 */
class LivenessController extends ControllerBase {

  /**
   * Implements event subscriber for handling events events.
   */
  public function events(Request $request) {
    $log_file = DRUPAL_ROOT . '/sites/default/files/liveness_log.txt';
    if (!file_exists($log_file)) {
      return [
        '#markup' => $this->t('No liveness events found.'),
      ];
    }

    // Default sorting options.
    $sort_by = $request->query->get('sort_by', 'timestamp');
    $sort_order = $request->query->get('sort_order', 'desc');
    $filter_environment = $request->query->get('filter_environment', '');

    $events = file($log_file);
    $events = array_map(function ($event) {
      preg_match('/(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) - (.*)/', $event, $matches);
      return [
        'timestamp' => strtotime($matches[1]),
        'event' => $event,
        'name' => $matches[2],
      ];
    }, $events);

    if (!empty($filter_environment)) {
      $events = array_filter($events, function ($event) use ($filter_environment) {
        return stripos($event['name'], $filter_environment) !== FALSE;
      });
    }

    usort($events, function ($a, $b) use ($sort_by, $sort_order) {
      if ($sort_by == 'timestamp') {
        $cmp = $a['timestamp'] - $b['timestamp'];
      }
      elseif ($sort_by == 'name') {
        $cmp = strcmp($a['name'], $b['name']);
      }
      return $sort_order == 'desc' ? -$cmp : $cmp;
    });

    return [
      'sort_form' => $this->formBuilder()->getForm('Drupal\liveness\Form\LivenessSortForm'),
      'events' => [
        '#theme' => 'liveness_event',
        '#events' => array_column($events, 'event'),
      ],
    ];
  }

}

==> liveness-1.0.5.tar.gz: liveness/src/Controller/LivenessController.php <==
<?php

namespace Drupal\liveness\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;

class LivenessController extends ControllerBase {

  public function events(Request $request) {
    $log_file = DRUPAL_ROOT . '/sites/default/files/liveness_log.txt';
    if (!file_exists($log_file)) {
      return [
        '#markup' => $this->t('No liveness events found.'),
      ];
    }

    // Default sorting options
    $sort_by = $request->query->get('sort_by', 'timestamp');
    $sort_order = $request->query->get('sort_order', 'desc');
    $filter_environment = $request->query->get('filter_environment', '');

    $events = file($log_file);
    $events = array_map(function($event) {
      preg_match('/(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) - (.*)/', $event, $matches);
      return [
        'timestamp' => strtotime($matches[1]),
        'event' => $event,
        'name' => $matches[2],
      ];
    }, $events);

    if (!empty($filter_environment)) {
      $events = array_filter($events, function($event) use ($filter_environment) {
        return stripos($event['name'], $filter_environment) !== FALSE;
      });
    }

    usort($events, function($a, $b) use ($sort_by, $sort_order) {
      if ($sort_by == 'timestamp') {
        $cmp = $a['timestamp'] - $b['timestamp'];
      } elseif ($sort_by == 'name') {
        $cmp = strcmp($a['name'], $b['name']);
      }
      return $sort_order == 'desc' ? -$cmp : $cmp;
    });

    return [
      'sort_form' => \Drupal::formBuilder()->getForm('Drupal\liveness\Form\LivenessSortForm'),
      'events' => [
        '#theme' => 'liveness_event',
        '#events' => array_column($events, 'event'),
      ],
    ];
  }
}
